pub struct Config {
pub auth: AuthConfig,
pub http: HttpConfig,
pub user: UserConfig,
pub transport: TransportConfig,
pub codecs: CodecConfig,
pub features: RuntimeFeatureFlags,
pub telemetry: TelemetryConfig,
pub diagnostics: DiagnosticsConfig,
}Fields
auth: AuthConfighttp: HttpConfiguser: UserConfigtransport: TransportConfigcodecs: CodecConfigfeatures: RuntimeFeatureFlagstelemetry: TelemetryConfigdiagnostics: DiagnosticsConfigImplementations
Sourceimpl Config
impl Config
Sourcepub fn from_env() -> Result<Self>
pub fn from_env() -> Result<Self>
Errors
Returns an error when a required operator environment variable is missing, an environment value cannot be parsed, a constrained value is outside its accepted range, telemetry export is requested without the required cargo feature, or transport cross-field validation rejects the advertised address, RTC port range, worker count, or room policy.
fn from_var_lookup(get_var: impl Fn(&str) -> Option<String>) -> Result<Self>